API
===

.. currentmodule:: papermill.api

Notebook
--------

.. autoclass:: papermill.api.Notebook
    :members:

Notebook Collection
-------------------

.. autoclass:: papermill.api.NotebookCollection
    :members:

Functions
---------

.. _display:

.. autofunction:: display

.. autofunction:: read_notebook

.. autofunction:: read_notebooks

.. autofunction:: record